@@ -2,6 +2,9 @@ from pkg_resources import get_distribution, DistributionNotFound
 
 APP_NAME_SHORT = "sett"
 APP_NAME_LONG = "Secure Encryption and Transfer Tool"
+URL_READTHEDOCS = "https://sett.readthedocs.io"
+URL_GITLAB = "https://gitlab.com/biomedit/sett"
+URL_GITLAB_ISSUES = URL_GITLAB + '/-/issues'
 
 __project_name__ = "sett"
 try:
