@@ -1,5 +1,10 @@
 #!/usr/bin/env python3
-"""Secure Encryption and Transfer Tool."""
+# The {} placeholders in the docstring are to be replaced with URL_HELP
+# and URL_GITLAB_ISSUES whenever the docstring is used.
+"""Secure Encryption and Transfer Tool
+For detailed documentation see: {}
+To report an issue, please use: {}
+"""
 
 import os
 import json
@@ -25,6 +30,7 @@ from ..workflows.upload_keys import upload_keys
 from ..protocols import parse_protocol, __all__ as available_protocols
 from ..core.versioncheck import check_version
 from ..core.error import UserError
+from .. import URL_READTHEDOCS, URL_GITLAB_ISSUES
 
 
 def parse_dict(s):
@@ -104,7 +110,7 @@ def load_config_check():
 
 
 class Cli(Subcommands):
-    description = __doc__
+    description = __doc__.format(URL_READTHEDOCS, URL_GITLAB_ISSUES)
     version = __version__
     config = load_config_check()
     logger = logging.getLogger()
