@@ -33,8 +33,21 @@ def to_user_error(error_types: Union[Exception, Tuple[Exception, ...]]):
     return _to_user_error
 
 
+def to_user_error_gen(error_types: Union[Exception, Tuple[Exception, ...]]):
+    """A decorator to turn errors of type :error_types: into UserError"""
+    def _to_user_error(f):
+        @wraps(f)
+        def wrapped(*args, **kwargs):
+            try:
+                yield from f(*args, **kwargs)
+            except error_types as e:
+                raise UserError(format(e))
+        return wrapped
+    return _to_user_error
+
+
 validate_pub_key = to_user_error(RuntimeError)(crypt.validate_pub_key)
-validated_keys_by_ids = to_user_error(
+validated_keys_by_ids = to_user_error_gen(
     (RuntimeError, gpg.cmd.GPGError))(
         partial(crypt.validated_keys_by_ids, url_opener=urlopen))
 refresh_keys = to_user_error(
@@ -42,7 +55,8 @@ refresh_keys = to_user_error(
         partial(crypt.refresh_keys, url_opener=urlopen))
 fingerprint2keyid = to_user_error(RuntimeError)(crypt.fingerprint2keyid)
 verify_metadata_signature = to_user_error(
-    RuntimeError)(crypt.verify_metadata_signature)
+    RuntimeError)(
+        partial(crypt.verify_metadata_signature, url_opener=urlopen))
 
 
 @to_user_error(gpg.cmd.GPGError)
@@ -167,9 +181,8 @@ def retrieve_keys(gpg_store: GPGStore,
 
     # If asked to do so, refresh keys by re-downloading them from keyserver.
     if with_refresh_keys:
-        pub_keys = list(refresh_keys(keys=pub_keys,
-                                     gpg_store=gpg_store, sigs=True))
-
+        pub_keys = refresh_keys(keys=pub_keys,
+                                gpg_store=gpg_store, sigs=True)
     # Verify keys are signed and non-revoked.
     for key in pub_keys:
         validate_pub_key(key, validation_keyid, keyserver_url)
