@@ -20,6 +20,7 @@ from ..core.error import UserError
 from ..core.versioncheck import check_version
 from ..workflows import decrypt, encrypt, transfer
 from ..utils.config import load_config
+from ..__init__ import URL_READTHEDOCS, URL_GITLAB, URL_GITLAB_ISSUES
 
 Key = crypt.gpg.Key
 
@@ -67,10 +68,19 @@ class MainWindow(QtWidgets.QMainWindow):
         menu_file = menu.addMenu("&File")
         menu_file.addAction(action_exit)
 
+        action_help = QtWidgets.QAction(QtGui.QIcon(),
+                                        "Sett documentation", self)
+        action_help.triggered.connect(open_url(URL_READTHEDOCS))
+        action_bug_report = QtWidgets.QAction(QtGui.QIcon(),
+                                              "Report an issue", self)
+        action_bug_report.triggered.connect(open_url(URL_GITLAB_ISSUES))
+
         action_about = QtWidgets.QAction(QtGui.QIcon(), "About", self)
         action_about.triggered.connect(self.show_about)
 
         menu_help = menu.addMenu("&Help")
+        menu_help.addAction(action_help)
+        menu_help.addAction(action_bug_report)
         menu_help.addAction(action_about)
 
     def closeEvent(self, event):
@@ -103,7 +113,20 @@ class MainWindow(QtWidgets.QMainWindow):
     def show_about(self):
         msg = QtWidgets.QMessageBox(parent=self)
         msg.setWindowTitle(f"About {APP_NAME_SHORT}")
-        msg.setText(f"{APP_NAME_LONG}\n\nVersion {__version__}")
+        msg.setIcon(QtWidgets.QMessageBox.Information)
+        msg.setTextFormat(QtCore.Qt.RichText)
+        msg.setText(
+            f"{APP_NAME_LONG}<br>"
+            f"Version {__version__}<br><br>"
+            f"For documentation go to "
+            f"<a href='{URL_READTHEDOCS}'>{URL_READTHEDOCS}</a><br>"
+            f"To report an issue go to "
+            f"<a href='{URL_GITLAB_ISSUES}'>{URL_GITLAB_ISSUES}</a><br>"
+            f"Source code is available at "
+            f"<a href='{URL_GITLAB}'>{URL_GITLAB}</a><br><br>"
+            f"{APP_NAME_SHORT} is developed as part of the "
+            f"<a href='https://sphn.ch'>Swiss Personalized Health Network "
+            f"initiative</a>")
         msg.show()
 
 
@@ -652,18 +675,23 @@ class KeyGenDialog(QtWidgets.QDialog):
     def post_key_creation(self, key: Key):
         msg = QtWidgets.QMessageBox()
         msg.setWindowTitle("GPG Key Generation")
+        msg.setIcon(QtWidgets.QMessageBox.Information)
         try:
             revocation_cert = crypt.create_revocation_certificate(
                 key.fingerprint, self.text_pass.text(),
                 self.parent().app_data.config.gpg_store)
             msg.setText(
-                "Key has been successfully generated. "
-                "Additionally, a revocation certificate has been created. "
-                "It can be used to revoke your key, e.g. if your key has been "
-                "compromised, lost, or you forgot your password. "
-                "Copy the revocation certificate to a safe location: "
-                "anyone can use the certificate to revoke your key.")
+                "Your new key has been successfully generated.\n\n"
+                "Additionally, a revocation certificate was also created. "
+                "It can be used to revoke your key in the eventuality that it "
+                "gets compromised, lost, or that you forgot your password.\n"
+                "Please store the revocation certificate below in a safe "
+                "location, as anyone can use it to revoke your key.")
             msg.setDetailedText(revocation_cert.decode())
+            # Programatically click the "Show Details..." button so that the
+            # certificate is shown by default.
+            click_show_details(msgbox=msg)
+
         except UserError:
             msg.setIcon(QtWidgets.QMessageBox.Warning)
             msg.setText(
@@ -856,7 +884,8 @@ class KeysTab(QtWidgets.QWidget):
 
     @staticmethod
     def key_to_text(key: Key) -> str:
-        return f"{key.uids[0]}\n{key.key_id}\n{key.fingerprint}"
+        return(f"User ID: {key.uids[0]}\n"
+               f"Fingerprint: {key.fingerprint}")
 
     def create_public_keys_btn_group(self):
         btn_download = QtWidgets.QPushButton("Download keys")
@@ -960,6 +989,7 @@ class KeysTab(QtWidgets.QWidget):
         msg = QtWidgets.QMessageBox()
         msg.setIcon(QtWidgets.QMessageBox.Question)
         msg.setWindowTitle("Delete public key")
+        msg.setText("Do you really want to delete the following public key?")
         msg.setStandardButtons(
             QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel)
         msg_warn = QtWidgets.QMessageBox()
@@ -977,10 +1007,8 @@ class KeysTab(QtWidgets.QWidget):
                     "as GnuPG (Linux, MacOS) or Kleopatra (Windows).")
                 msg_warn.exec_()
                 continue
-            msg.setText(
-                "Do you want to delete the public key for "
-                f"{key.uids[0]}?")
             msg.setDetailedText(self.key_to_text(key))
+            click_show_details(msgbox=msg)
             status = msg.exec_()
             if status == QtWidgets.QMessageBox.Ok:
                 try:
@@ -998,6 +1026,8 @@ class KeysTab(QtWidgets.QWidget):
         msg.setText(
             "Do you want to upload the selected key to the key server?")
         msg.setIcon(QtWidgets.QMessageBox.Question)
+        msg.setStandardButtons(
+                QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel)
         msg_ok = QtWidgets.QMessageBox()
         msg_ok.setIcon(QtWidgets.QMessageBox.Information)
         msg_ok.setWindowTitle("Send public key")
@@ -1008,8 +1038,7 @@ class KeysTab(QtWidgets.QWidget):
         for index in self.pub_keys_view.selectedIndexes():
             key = index.model().get_value(index)
             msg.setDetailedText(self.key_to_text(key))
-            msg.setStandardButtons(
-                QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel)
+            click_show_details(msgbox=msg)
             status = msg.exec_()
             if status == QtWidgets.QMessageBox.Ok:
                 worker = Worker(crypt.upload_keys, [key.fingerprint],
@@ -1024,9 +1053,10 @@ class KeysTab(QtWidgets.QWidget):
     def request_signature(self):
         msg = QtWidgets.QMessageBox()
         msg.setWindowTitle("Key signing request")
-        msg.setText(
-            "Do you want to request signature for the selected key?")
+        msg.setText("Do you want to request signature for the selected key?")
         msg.setIcon(QtWidgets.QMessageBox.Question)
+        msg.setStandardButtons(
+                QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel)
         msg_ok = QtWidgets.QMessageBox()
         msg_ok.setIcon(QtWidgets.QMessageBox.Information)
         msg_ok.setWindowTitle("Key signing request")
@@ -1037,8 +1067,7 @@ class KeysTab(QtWidgets.QWidget):
         for index in self.pub_keys_view.selectedIndexes():
             key = index.model().get_value(index)
             msg.setDetailedText(self.key_to_text(key))
-            msg.setStandardButtons(
-                QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel)
+            click_show_details(msgbox=msg)
             status = msg.exec_()
             if status == QtWidgets.QMessageBox.Ok:
                 worker = Worker(
@@ -1093,3 +1122,25 @@ class FieldMapping:
                 self._mapping[key](val)
             except KeyError:
                 raise ValueError(f"Invalid field `{key}` found in your config file")
+
+def click_show_details(msgbox: QtWidgets.QMessageBox):
+    for button in msgbox.buttons():
+        if msgbox.buttonRole(button) is \
+        QtWidgets.QMessageBox.ButtonRole.ActionRole:
+            button.click()
+
+def open_url(url: str):
+    """Retruns a function that will opens the specified URL in the user's
+    default browser when called. The function that is returned has no
+    arguments.
+    :param url: URL to open.
+    :returns: function that opens specifed URL.
+    """
+    def open_url_template():
+        if not QtGui.QDesktopServices.openUrl(QtCore.QUrl(url)):
+            msg_warn = QtWidgets.QMessageBox()
+            msg_warn.setWindowTitle("Warning")
+            msg_warn.setText(f"Unable to open URL at \n{url}.")
+            msg_warn.setIcon(QtWidgets.QMessageBox.Warning)
+            msg_warn.exec_()
+    return open_url_template
