@@ -88,6 +88,9 @@ def encrypt(files: List[str],
     """
     if sender is None:
         sender = config.default_sender or config.gpg_store.default_key()
+        if sender is None:
+            raise UserError(
+                "Sender not specified but no default sender could be determined")
 
     # Check if project is valid:
     if not offline:
